@@ -1,4 +1,4 @@
-from src.vyze.universe import parse_object_def, load_universe_from_file, load_universe_from_api, simplify_object_ident
+from src.vyze.universe import parse_object_def, load_universe_from_file, load_universe_from_api, simplify_object_ident, get_full_object_ident
 
 
 def test_object_def__1():
@@ -39,10 +39,19 @@ def test_simplify_object_ident__1():
 def test_simplify_object_ident__2():
     assert simplify_object_ident('base.object/base', 'data') == 'base.object'
     assert simplify_object_ident('base.object/image', 'data') == 'base.object/image'
+    assert simplify_object_ident('base.object/data', 'data') == 'base.object/'
+    assert simplify_object_ident('base.object/', 'data') == 'base.object/'
     assert simplify_object_ident('base.object', 'data') == 'base.object'
     assert simplify_object_ident('object', 'data') == 'object'
 
 
+def test_get_full_object_ident__1():
+    assert get_full_object_ident('object', 'test') == 'test.object/test'
+    assert get_full_object_ident('base.object', 'test') == 'base.object/base'
+    assert get_full_object_ident('base.object/', 'data') == 'base.object/data'
+    assert get_full_object_ident('base.object/test', 'data') == 'base.object/test'
+
+
 def test_load_universe_from_file():
     universe = load_universe_from_file('./test_universe.yml')
     assert len(universe._description) > 0
